==> owncloud-8.2.2p3.tgz: owncloud/apps/activity/l10n/id.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitas",
    "Personal activity feed for %s" : "Feed aktivitas pribadi untuk %s",
    "Your feed URL is invalid" : "URL feed Anda tidak sah",
    "Your settings have been updated." : "Pengaturan Anda telah diperbarui.",
    "Mail" : "Email",
    "Stream" : "Stream",
    "Activities" : "Aktivitas",
    "Error loading activities" : "Kesalahan memuat aktivitas",
    "No activities" : "Tidak ada aktivitas",
    "This stream will show events like additions, changes & shares" : "Stream ini akan menampilkan agenda seperti penambahan, perubahan & berbagi",
    "There are no events for this filter" : "Tidak ada agenda untuk penyaring ini",
    "Activity notification" : "Pemberitahuan aktivitas",
    "All Activities" : "Semua Aktivitas",
    "Activities by you" : "Aktivitas oleh Anda",
    "Activities by others" : "Aktivitas oleh orang lain",
    "\"remote user\"" : "\"remote user\"",
    "in %s" : "dalam %s",
    "%s and %s" : "%s dan %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s dan <strong %s>%n lainnya</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s dan %n lainnya"],
    "Hello %s," : "Helo %s,",
    "You are receiving this email because the following things happened at %s" : "Anda menerima email ini karena sesuatu telah terjadi pada %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* dan %n lagi "],
    "Notifications" : "Pemberitahuan",
    "List your own actions in the stream" : "Daftar aksi oleh Anda didalam alir",
    "Notify about your own actions via email" : "Beritahukan tetang aksi oleh Anda via email",
    "You need to set up your email address before you can receive notification emails." : "Anda perlu menyetal alamat email Anda sebelum Anda dapat menerima email pemberitahuan.",
    "Send emails:" : "Kirim email:",
    "Hourly" : "Setiap jam",
    "Daily" : "Setiap hari",
    "Weekly" : "Setiap minggu",
    "Activity feed" : "Feed aktivitas",
    "Enable RSS feed" : "Aktifkan RSS feed",
    "No activity yet" : "Masih tidak ada aktivitas",
    "No more events to load" : "Tidak ada lagi acara untuk dimuat",
    "Files" : "Berkas",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s dan <strong class=\"has-tooltip\" title=\"%s\">%n lainnya</strong>"]
},
"nplurals=1; plural=0;");

==> owncloud-9.0.3.tgz: owncloud/apps/activity/l10n/id.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitas",
    "Personal activity feed for %s" : "Feed aktivitas pribadi untuk %s",
    "Your feed URL is invalid" : "URL feed Anda tidak sah",
    "Your settings have been updated." : "Pengaturan Anda telah diperbarui.",
    "Mail" : "Email",
    "Stream" : "Stream",
    "Activities" : "Aktivitas",
    "Error loading activities" : "Kesalahan memuat aktivitas",
    "No activities" : "Tidak ada aktivitas",
    ", " : ", ",
    "This stream will show events like additions, changes & shares" : "Stream ini akan menampilkan agenda seperti penambahan, perubahan & berbagi",
    "There are no events for this filter" : "Tidak ada agenda untuk penyaring ini",
    "Today" : "Hari Ini",
    "Yesterday" : "Kemarin",
    "\"remote user\"" : "\"remote user\"",
    "Activity notification" : "Pemberitahuan aktivitas",
    "All Activities" : "Semua Aktivitas",
    "Activities by you" : "Aktivitas oleh Anda",
    "Activities by others" : "Aktivitas oleh orang lain",
    "%s and %s" : "%s dan %s",
    "Hello %s," : "Helo %s,",
    "You are receiving this email because the following things happened at %s" : "Anda menerima email ini karena sesuatu telah terjadi pada %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* dan %n lagi "],
    "List your own actions in the stream" : "Daftar aksi oleh Anda didalam alir",
    "Notify about your own actions via email" : "Beritahukan tetang aksi oleh Anda via email",
    "You need to set up your email address before you can receive notification emails." : "Anda perlu menyetal alamat email Anda sebelum Anda dapat menerima email pemberitahuan.",
    "Send emails:" : "Kirim email:",
    "Hourly" : "Setiap jam",
    "Daily" : "Setiap hari",
    "Weekly" : "Setiap minggu",
    "Activity feed" : "Feed aktivitas",
    "Enable RSS feed" : "Aktifkan RSS feed",
    "No activity yet" : "Masih tidak ada aktivitas",
    "No more events to load" : "Tidak ada lagi acara untuk dimuat",
    "Files" : "Berkas"
},
"nplurals=1; plural=0;");
